@@ -3,7 +3,7 @@
 
 
 cd "$(dirname "$0")"
-version="2.9.0"
+version="3.1.0"
 gtk="gtk3"
 
 mkdir builder
@@ -31,7 +31,7 @@ fi
 
 
 # create packages for Debian and Ubuntu
-for serie in experimental plucky oracular noble jammy focal bionic xenial trusty; do
+for serie in experimental questing plucky oracular noble jammy focal bionic xenial trusty; do
 
 	printf "\n\n#################################################################### $serie ## awf-gtk3 ##\n\n"
 	if [ $serie = "experimental" ]; then
@@ -50,15 +50,16 @@ for serie in experimental plucky oracular noble jammy focal bionic xenial trusty
 	dh_make -s -y -f ../awf-extended-$version.tar.gz -p awf-$gtk
 
 	rm -rf debian/*/*ex debian/*ex debian/*EX debian/README* debian/*doc*
-	cp scripts/debian-$gtk/* data/*.1 debian/
-	cp scripts/debian/*$gtk* scripts/debian/copyright scripts/debian/metadata scripts/debian/watch scripts/debian/clean debian/
+	cp scripts/debian-$gtk/* debian/
+	cp scripts/debian/*$gtk* scripts/debian/copyright scripts/debian/metadata scripts/debian/watch debian/
 	head -n -1 debian/*$gtk*.install > debian/install ; rm debian/awf-$gtk.install
 	rm -f debian/deb.sh
-	mv debian/metadata debian/upstream/metadata
+	mkdir debian/upstream ; mv debian/metadata debian/upstream/metadata
 
 	if [ $serie = "experimental" ]; then
 		mv debian/control.debian debian/control
 		mv debian/changelog.debian debian/changelog
+		rm -f debian/*.mx debian/*.debian debian/*.ubuntu
 		echo "=========================== buildpackage ($serie) =="
 		dpkg-buildpackage -us -uc
 	else
@@ -75,17 +76,19 @@ for serie in experimental plucky oracular noble jammy focal bionic xenial trusty
 		elif [ $serie = "bionic" ]; then
 			mv debian/control.ubuntu debian/control
 			sed -i 's/dh $@/dh $@ --with autoreconf/g' debian/rules
+			sed -i 's/execute_before_dh_install:/override_dh_update_autotools_config:/g' debian/rules
 			sed -i 's/debhelper-compat (= 13)/debhelper-compat (= 9), dh-autoreconf/g' debian/control
 		elif [ $serie = "xenial" ]; then
 			mv debian/control.ubuntu debian/control
 			sed -i 's/dh $@/dh $@ --with autoreconf/g' debian/rules
+			sed -i 's/execute_before_dh_install:/override_dh_update_autotools_config:/g' debian/rules
 			sed -i 's/debhelper-compat (= 13)/debhelper (>= 9), dh-autoreconf/g' debian/control
 			sed -i ':a;N;$!ba;s/Rules-Requires-Root: no\n//g' debian/control
 			echo 9 > debian/compat
 		elif [ $serie = "trusty" ]; then
 			mv debian/control.ubuntu debian/control
 			sed -i 's/dh $@/dh $@ --with autotools_dev,autoreconf/g' debian/rules
-			sed -i 's/override_dh_update_autotools_config/override_dh_autotools-dev_updateconfig/g' debian/rules
+			sed -i 's/execute_before_dh_install:/override_dh_autotools-dev_updateconfig:/g' debian/rules
 			sed -i 's/debhelper-compat (= 13)/debhelper (>= 9), autotools-dev, dh-autoreconf/g' debian/control
 			sed -i ':a;N;$!ba;s/Rules-Requires-Root: no\n//g' debian/control
 			echo 9 > debian/compat
@@ -102,26 +105,28 @@ for serie in experimental plucky oracular noble jammy focal bionic xenial trusty
 			sed -i 's/experimental/'$serie'/g' debian/changelog
 			sed -i 's/-1) /-1+'$serie') /' debian/changelog
 		fi
-		rm -f debian/*.mx debian/*.debian
+		rm -f debian/*.mx debian/*.debian debian/*.ubuntu
 		echo "=========================== buildpackage ($serie) =="
 		dpkg-buildpackage -us -uc -ui -d -S
 	fi
-	echo "=========================== debsign ($serie) =="
 	cd ..
 
 	if [ $serie = "experimental" ]; then
-		debsign awf-${gtk}_$version*.changes
 		echo "=========================== lintian ($serie) =="
-		lintian -EviIL +pedantic awf-$gtk*$version*.deb
+		lintian -EviIL +pedantic awf-${gtk}_$version*.changes
+		rm *amd64.changes
 	elif [ $serie = "unstable" ]; then
+		echo "=========================== debsign ($serie) =="
 		debsign awf-$gtk*$version-*_source.changes
 	else
+		echo "=========================== debsign ($serie) =="
 		debsign awf-$gtk*$version*$serie*source.changes
 	fi
 	cd ..
 done
 
 printf "\n\n"
+rm builder/*dbgsym*deb
 ls -dlth "$PWD/"builder/*.deb "$PWD/"builder/*.changes
 printf "\n"
 rm -rf builder/*/
\ No newline at end of file
